@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps;
 use strict;
 use warnings;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 use Hash::Util 'lock_keys';
 use List::Util 'first';
@@ -96,6 +96,8 @@ sub new {
     if (!$installer) {
 	if      ($os eq 'freebsd') {
 	    $installer = 'pkg';
+	} elsif ($os eq 'gnukfreebsd') {
+	    $installer = 'apt-get';
 	} elsif ($os eq 'linux') {
 	    if      (__PACKAGE__->_is_linux_debian_like($linuxdistro)) {
 		$installer = 'apt-get';
@@ -829,6 +831,10 @@ The default mapping has support for FreeBSD and Debian-like systems
 (but details are missing for distributions like Ubuntu or Mint).
 Support for other systems is missing.
 
+=item * Should gnukfreebsd be handled like debian?
+
+Maybe gnukfreebsd should be included in the "like_debian" condition?
+
 =back
 
 =head1 CREDITS
