@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps::Mapping;
 use strict;
 use warnings;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 # shortcuts
 #  os and distros
@@ -93,6 +93,10 @@ sub mapping {
       [like_debian,
        [package => 'pkg-config | pkgconf']]], # XXX pkg-config probably needed by much more CPAN distributions...
 
+     [cpanmod => 'Alien::sispmctl',
+      [like_debian,
+       [package => 'libusb-dev']]],
+
      [cpanmod => 'Alien::SVN',
       [os_freebsd,
        # does not work, configure does not recognize sqlite
@@ -677,7 +681,7 @@ sub mapping {
       [like_debian,
        [package => 'libprotoc-dev']]],
 
-     [cpanmod => ['Graphics::GnuplotIF', 'Gnuplot::Simple'],
+     [cpanmod => ['Graphics::GnuplotIF', 'Gnuplot::Simple', 'Chart::Gnuplot'],
       [package => 'gnuplot']],
 
      [cpanmod => 'Graphics::Plotter',
@@ -1512,6 +1516,12 @@ sub mapping {
      [cpanmod => 'Video::FFmpeg',
       [package => 'ffmpeg']], # on Debian only found in backports or www.deb-multimedia.org; still does not build because avformat.h is not available
 
+     [cpanmod => 'Video::Xine',
+      [os_freebsd,
+       [package => 'libxine']],
+      [like_debian,
+       [package => 'libxine2-dev']]],
+
      [cpanmod => 'WordNet::QueryData',
       [os_freebsd,
        [package => 'wordnet']],
@@ -1601,6 +1611,12 @@ sub mapping {
       [like_debian,
        [package => 'libxosd-dev']]],
 
+     [cpanmod => 'X11::FullScreen',
+      [os_freebsd,
+       [package => 'imlib2']],
+      [like_debian,
+       [package => 'imlib2-dev']]],
+
      [cpanmod => 'X11::GUITest',
       [like_debian,
        [package => ['libxt-dev', 'libxtst-dev']]],
